import { AxiosError } from "axios";
import { LOGIN_URI, SIGNUP_URI } from "../constants/api";
import { client } from "./config";

const initialState: IEmptyResponseState = {
  data: null,
  error: AxiosError
}

interface IAuthentication {
  username: String
  password: String
}

async function createAccountService({ username, password }: IAuthentication) {
  const newState = { ...initialState };
  const url = `${SIGNUP_URI}`
  try {
    const response = await client({ method: 'POST', url: url, data: { username, password } })
    newState.data = response.data
    newState.error = null
    return newState
  } catch (error) {
    newState.error = error
    return newState
  }
}

async function loginService({ username, password }: IAuthentication) {
  const newState = { ...initialState };
  const url = `${LOGIN_URI}`
  try {
    const response = await client({ method: 'POST', url: url, data: { username, password } })
    newState.data = response.data
    newState.error = null
    return newState
  } catch (error) {
    newState.error = error
    return newState
  }

}

export {
  loginService,
  createAccountService
};